package com.example.myapplication;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;

import android.os.Bundle;
import android.util.Log;

import org.mozilla.geckoview.GeckoResult;
import org.mozilla.geckoview.GeckoRuntime;
import org.mozilla.geckoview.GeckoSession;
import org.mozilla.geckoview.GeckoView;
import org.mozilla.geckoview.WebExtension;

public class MainActivity extends AppCompatActivity {

    private WebExtension.Port mPort;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        GeckoView view = findViewById(R.id.geckoview);
        GeckoSession session = new GeckoSession();
        GeckoRuntime runtime = GeckoRuntime.create(this);

        session.open(runtime);
        view.setSession(session);
        session.loadUri("https://httpdump.io/iv0zz"); // Or any other URL... https://httpdump.io/iv0zz

        // This delegate will handle all communications from and to a specific Port
        // object
        WebExtension.PortDelegate portDelegate = new WebExtension.PortDelegate() {
            public WebExtension.Port port = null;

            public void onPortMessage(final @NonNull Object message,
                                      final @NonNull WebExtension.Port port) {
                // This method will be called every time a message is sent from the
                // extension through this port. For now, let's just log a
                // message.
                Log.d("PortDelegate", "Received message from WebExtension: "
                        + message);
            }

            public void onDisconnect(final @NonNull WebExtension.Port port) {
                // After this method is called, this port is not usable anymore.
                if (port == mPort) {
                    mPort = null;
                }
            }
        };

        // This delegate will handle requests to open a port coming from the
        // extension
        WebExtension.MessageDelegate messageDelegate = new WebExtension.MessageDelegate() {
            @Nullable
            public void onConnect(final @NonNull WebExtension.Port port) {
                // Let's store the Port object in a member variable so it can be
                // used later to exchange messages with the WebExtension.
                mPort = port;

                // Registering the delegate will allow us to receive messages sent
                // through this port.
                mPort.setDelegate(portDelegate);
            }
        };

        runtime.getWebExtensionController()
                .installBuiltIn("resource://android/assets/messaging/")
                .accept(
                        // Register message delegate for background script
                        extension -> extension.setMessageDelegate(messageDelegate, "browser"),
                        e -> Log.e("MessageDelegate", "Error registering WebExtension", e)
                );

        // ... other
    }
}