/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

// Establish connection with app
"use strict";
const port = browser.runtime.connectNative("browser");
port.onMessage.addListener(response => {
  // Let's just echo the message back
  port.postMessage(`Received: ${JSON.stringify(response)}`);
});
port.postMessage("Hello from WebExtension!");

function setHeader(headers, name, value) {
    for (var header of headers) {
        if (header.name.toLowerCase() == name.toLowerCase()) {
            header.value = value;
            return;
        }
    }
    headers.push({ name : name, value : value });
}

function removeHeader(headers, name) {
    for (var i = 0; i < headers.length; i++) {
        if (headers[i].name.toLowerCase() == name.toLowerCase()) {
            headers.splice(i, 1);
            return;
        }
    }
}

function changeResponseHeaders(details) {
    setHeader(details.responseHeaders, "User-Agent", "TestBrowser");
    port.postMessage('changeResponseHeaders: ' + details.responseHeaders);
	//console.log(details.responseHeaders);

    return {
        responseHeaders: details.responseHeaders
    };
}

function changeRequestHeaders(details) {
    setHeader(details.requestHeaders, "User-Agent", "TestBrowser");
    port.postMessage('changeRequestHeaders: ' + details.requestHeaders);
	//console.log(details.requestHeaders);

    return {
        requestHeaders: details.requestHeaders
    };
}

chrome.webRequest.onBeforeSendHeaders.addListener(
  changeRequestHeaders, {
        urls: ["*://*/*"],
        types: ["main_frame", "sub_frame"]
    }, ["blocking", "requestHeaders"]
);

chrome.webRequest.onHeadersReceived.addListener(
    changeResponseHeaders, {
        urls: ["*://*/*"],
        types: ["main_frame", "sub_frame"]
    }, ["blocking", "responseHeaders"]
)